@@ -7,9 +7,9 @@ impl<R: repr::Repr> Parser<'_, R> {
     pub fn directive(&mut self) -> Result<(), PError> {
         self.sym(b'%')?;
         self.context(|p| {
-            if p.seq(b"YAML").is_ok() {
+            if p.sym_seq(b"YAML").is_ok() {
                 p.directive_yaml()
-            } else if p.seq(b"TAG").is_ok() {
+            } else if p.sym_seq(b"TAG").is_ok() {
                 p.directive_tag()
             } else {
                 // Unknown - ignore
@@ -23,7 +23,7 @@ impl<R: repr::Repr> Parser<'_, R> {
         self.ws(TakeOpt::More(1))?;
         if self.version_checked {
             self.err("checked version")
-        } else if self.seq(b"1.2").is_err() {
+        } else if self.sym_seq(b"1.2").is_err() {
             self.err("version")
         } else {
             self.version_checked = true;
