@@ -39,7 +39,7 @@ impl<R: repr::Repr> Parser<'_, R> {
         self.take_while(u8::is_ascii_digit, TakeOpt::More(0))?;
         let s = self.text();
         self.bound()?;
-        Ok(s)
+        Ok(s.trim_end_matches(|c| ".0".contains(c)).to_string())
     }
 
     /// Match float with scientific notation.
@@ -53,31 +53,6 @@ impl<R: repr::Repr> Parser<'_, R> {
         Ok(s)
     }
 
-    /// Match NaN.
-    pub fn nan(&mut self) -> Result<(), PError> {
-        self.sym(b'.')?;
-        for s in [b"nan", b"NaN", b"NAN"] {
-            if self.seq(s).is_ok() {
-                self.bound()?;
-                return Ok(());
-            }
-        }
-        Err(PError::Mismatch)
-    }
-
-    /// Match inf, return true if the value is positive.
-    pub fn inf(&mut self) -> Result<bool, PError> {
-        let b = self.sym(b'-').is_err();
-        self.sym(b'.')?;
-        for s in [b"inf", b"Inf", b"INF"] {
-            if self.seq(s).is_ok() {
-                self.bound()?;
-                return Ok(b);
-            }
-        }
-        Err(PError::Mismatch)
-    }
-
     /// Match quoted string.
     pub fn string_quoted(&mut self, sym: u8, ignore: &[u8]) -> Result<String, PError> {
         self.context(|p| {
@@ -91,7 +66,7 @@ impl<R: repr::Repr> Parser<'_, R> {
                 p.take_while(Self::not_in(&[b'\n', b'\r', b'\\', sym]), TakeOpt::More(0))?;
                 v.push_str(&p.text());
                 p.forward();
-                if p.seq(ignore).is_ok() {
+                if p.sym_seq(ignore).is_ok() {
                     v.push(char::from(sym));
                 } else if let Ok(mut t) = p.gap(false) {
                     if v.ends_with('\\') {
@@ -137,9 +112,9 @@ impl<R: repr::Repr> Parser<'_, R> {
                 p.take_while(Self::not_in(&patt), TakeOpt::More(0))?;
                 v.push_str(&p.text());
                 p.forward();
-                if p.seq(b": ").is_ok()
+                if p.sym_seq(b": ").is_ok()
                     || (p.sym(b':').is_ok() && p.nl().is_ok())
-                    || p.seq(b" #").is_ok()
+                    || p.sym_seq(b" #").is_ok()
                 {
                     p.backward();
                     break;
@@ -178,19 +153,6 @@ impl<R: repr::Repr> Parser<'_, R> {
         })
     }
 
-    /// Match flow string and return the content.
-    pub fn string_flow(&mut self, level: usize, inner: bool) -> Result<String, PError> {
-        if let Ok(s) = self.string_quoted(b'\'', b"''") {
-            Ok(s)
-        } else if let Ok(s) = self.string_quoted(b'"', b"\\\"") {
-            Ok(Self::escape(&s))
-        } else if let Ok(s) = self.string_plain(level, inner) {
-            Ok(s)
-        } else {
-            Err(PError::Mismatch)
-        }
-    }
-
     /// Match literal string.
     pub fn string_literal(&mut self, level: usize) -> Result<String, PError> {
         self.sym(b'|')?;
@@ -366,8 +328,8 @@ impl<R: repr::Repr> Parser<'_, R> {
     /// Match newline characters.
     pub fn nl(&mut self) -> Result<(), PError> {
         self.context(|p| {
-            (p.seq(b"\r\n").is_ok()
-                || p.seq(b"\n\r").is_ok()
+            (p.sym_seq(b"\r\n").is_ok()
+                || p.sym_seq(b"\n\r").is_ok()
                 || p.sym(b'\n').is_ok()
                 || p.sym(b'\r').is_ok())
             .then(|| ())
@@ -380,15 +342,32 @@ impl<R: repr::Repr> Parser<'_, R> {
         self.take_while(u8::is_ascii_whitespace, opt)
     }
 
+    /// Match and define new indent size.
+    pub fn ind_define(&mut self, level: usize) -> Result<(), PError> {
+        assert!(level <= self.indent.len());
+        if level > 0 {
+            self.ind(level - 1)?;
+        }
+        let ind = self.count(|p| p.take_while(Self::is_in(b" "), TakeOpt::More(0)))?;
+        if level == self.indent.len() {
+            self.indent.push(ind);
+        } else {
+            self.indent[level] = ind;
+        }
+        Ok(())
+    }
+
     /// Match indent with previous level.
     ///
-    /// Return `true` if downgrading indent is allowed.
+    /// This sub-parser returns `true` if downgrading indent is used.
+    ///
+    /// The downgrading can only use a level as unit, not a whitespace.
     pub fn unind(&mut self, level: usize) -> Result<bool, PError> {
         if level > 0 {
             self.ind(level - 1)?;
             self.context(|p| Ok(p.ind(1).is_err()))
         } else {
-            self.ind(level)?;
+            self.ind(0)?;
             Ok(false)
         }
     }
