@@ -1,10 +1,56 @@
-//! Parser components.
+//! Parser components, includes parser error.
+//!
+//! This parser is a simple greedy algorithm that returns result when
+//! matched successfully; try next or return error when mismatched.
+//!
+//! Each pattern (the method of [`Parser`] type) is called "sub-parser",
+//! which returns a `Result<T, PError>` type, where `T` is the return type.
+//!
+//! # Errors
+//!
+//! ## Document
+//!
+//! **WRONG**: Invalid tag directive will be ignored.
+//!
+//! + document splitter: Error about the document splitter `---` / `...`.
+//! + checked version: Version directive `%YAML 1.2` is used again.
+//! + version: Version directive is wrong, must be `1.2`.
+//!
+//! ## Structure
+//!
+//! ### Flow Array
+//!
+//! + flow sequence item: Item in `[]` bracket is invalid.
+//!
+//! ### Flow Map
+//!
+//! + flow map key: Key of map item in `{}` bracket is invalid.
+//! + flow map value: Value of map item in `{}` bracket is invalid.
+//! + flow map splitter: Splitter `:` of map item in `{}` bracket is invalid.
+//!
+//! ### Array
+//!
+//! + sequence item: Item behind `-` indicator is invalid.
+//! + sequence terminator: The end of sequence is invalid, may caused by the last item
+//!   (like wrapped string).
+//!
+//! ### Map
+//!
+//! + map key: Key of map item is invalid.
+//! + map value: Value of map item is invalid.
+//! + map splitter: Splitter `:` of map item is invalid.
+//! + map terminator: The end of map is invalid, may caused by the last value
+//!   (like wrapped string).
 pub use self::{
     base::{TakeOpt, DEFAULT_PREFIX},
     error::PError,
 };
-use crate::*;
-use alloc::{string::String, vec};
+use crate::{repr::Repr, *};
+use alloc::{
+    string::{String, ToString},
+    vec,
+    vec::Vec,
+};
 use ritelinked::LinkedHashMap;
 
 mod base;
@@ -45,9 +91,9 @@ macro_rules! err {
 /// + Method [`Parser::forward`] is used to move on.
 /// + Method [`Parser::text`] is used to get the matched string.
 /// + Method [`Parser::backward`] is used to get back if mismatched.
-pub struct Parser<'a, R: repr::Repr> {
+pub struct Parser<'a, R: Repr> {
     doc: &'a [u8],
-    indent: usize,
+    indent: Vec<usize>,
     consumed: u64,
     pub(crate) version_checked: bool,
     pub(crate) tag: LinkedHashMap<String, String>,
@@ -63,16 +109,29 @@ pub struct Parser<'a, R: repr::Repr> {
 ///
 /// These sub-parser returns [`PError`], and failed immediately for [`PError::Terminate`].
 /// Additionally, they should eat the string by themself.
-impl<R: repr::Repr> Parser<'_, R> {
+///
+/// # Parameter `nest`
+///
+/// The `nest` parameter presents that the expression is in a **map** structure,
+/// includes grand parents.
+///
+/// If `nest` is false, the expression might in the document root.
+///
+/// # Parameter `inner`
+///
+/// The `inner` parameter presents that the expression is in a **flow** expression.
+impl<R: Repr> Parser<'_, R> {
     /// YAML entry point, return entire doc if exist.
-    pub fn parse(&mut self) -> Result<Array<R>, PError> {
+    pub fn parse(&mut self) -> Result<Seq<R>, PError> {
         loop {
-            if self.context(Self::directive).is_err() {
-                break;
+            match self.context(Self::directive) {
+                Ok(()) => (),
+                Err(PError::Mismatch) => break,
+                Err(e) => return Err(e),
             }
         }
         self.gap(true).unwrap_or_default();
-        self.seq(b"---").unwrap_or_default();
+        self.sym_seq(b"---").unwrap_or_default();
         self.gap(true).unwrap_or_default();
         self.forward();
         let mut v = vec![self.doc()?];
@@ -81,8 +140,8 @@ impl<R: repr::Repr> Parser<'_, R> {
             if self.food().is_empty() {
                 break;
             }
-            if self.seq(b"---").is_err() {
-                return self.err("splitter");
+            if self.sym_seq(b"---").is_err() {
+                return self.err("document splitter");
             }
             self.gap(true).unwrap_or_default();
             self.forward();
@@ -93,9 +152,11 @@ impl<R: repr::Repr> Parser<'_, R> {
 
     /// Match one doc block.
     pub fn doc(&mut self) -> Result<NodeBase<R>, PError> {
+        self.ind_define(0)?;
+        self.forward();
         let ret = self.scalar(0, false, false)?;
         self.gap(true).unwrap_or_default();
-        self.seq(b"...").unwrap_or_default();
+        self.sym_seq(b"...").unwrap_or_default();
         self.forward();
         Ok(ret)
     }
@@ -106,7 +167,7 @@ impl<R: repr::Repr> Parser<'_, R> {
             true
         } else {
             self.context(|p| {
-                let b = p.seq(b"---").is_ok() || p.seq(b"...").is_ok();
+                let b = p.sym_seq(b"---").is_ok() || p.sym_seq(b"...").is_ok();
                 if b {
                     p.backward();
                 }
@@ -124,7 +185,7 @@ impl<R: repr::Repr> Parser<'_, R> {
                 Ok(YamlBase::Str(s))
             } else {
                 err!(
-                    p.array(level, nest),
+                    p.seq(level, nest),
                     err!(p.map(level, nest, inner), p.scalar_term(level, inner))
                 )
             }
@@ -162,37 +223,39 @@ impl<R: repr::Repr> Parser<'_, R> {
 
     /// Match flow scalar terminal.
     pub fn scalar_term(&mut self, level: usize, inner: bool) -> Result<YamlBase<R>, PError> {
-        let yaml = if self.sym(b'~').is_ok() || self.seq(b"null").is_ok() {
-            YamlBase::Null
-        } else if self.seq(b"true").is_ok() {
-            YamlBase::Bool(true)
-        } else if self.seq(b"false").is_ok() {
-            YamlBase::Bool(false)
-        } else if self.nan().is_ok() {
-            YamlBase::Float("NaN".into())
-        } else if let Ok(b) = self.inf() {
-            YamlBase::Float(if b { "inf" } else { "-inf" }.into())
-        } else if let Ok(s) = self.float() {
-            YamlBase::Float(s.trim_end_matches(|c| ".0".contains(c)).into())
+        let yaml = if let Ok(s) = self.float() {
+            YamlBase::Float(s)
         } else if let Ok(s) = self.sci_float() {
             YamlBase::Float(s)
         } else if let Ok(s) = self.int() {
             YamlBase::Int(s)
         } else if let Ok(s) = self.anchor_use() {
             YamlBase::Anchor(s)
-        } else if let Ok(s) = self.string_flow(level, inner) {
+        } else if let Ok(s) = self.string_quoted(b'\'', b"''") {
             YamlBase::Str(s)
+        } else if let Ok(s) = self.string_quoted(b'"', b"\\\"") {
+            YamlBase::Str(Self::escape(&s))
+        } else if let Ok(s) = self.string_plain(level, inner) {
+            match s.as_str() {
+                "~" | "null" | "Null" | "NULL" => YamlBase::Null,
+                "true" | "True" | "TRUE" => YamlBase::Bool(true),
+                "false" | "False" | "FALSE" => YamlBase::Bool(false),
+                ".nan" | ".NaN" | ".NAN" => YamlBase::Float("NaN".to_string()),
+                ".inf" | ".Inf" | ".INF" => YamlBase::Float("inf".to_string()),
+                "-.inf" | "-.Inf" | "-.INF" => YamlBase::Float("-inf".to_string()),
+                _ => YamlBase::Str(s),
+            }
         } else {
             err!(
-                self.array_flow(level),
+                self.seq_flow(level),
                 err!(self.map_flow(level), Ok(YamlBase::Null))
             )?
         };
         Ok(yaml)
     }
 
-    /// Match flow array.
-    pub fn array_flow(&mut self, level: usize) -> Result<YamlBase<R>, PError> {
+    /// Match flow sequence.
+    pub fn seq_flow(&mut self, level: usize) -> Result<YamlBase<R>, PError> {
         self.sym(b'[')?;
         let mut v = vec![];
         loop {
@@ -204,7 +267,7 @@ impl<R: repr::Repr> Parser<'_, R> {
             self.forward();
             v.push(err!(
                 self.scalar(level + 1, false, true),
-                self.err("flow array item")
+                self.err("flow sequence item")
             )?);
             self.inv(TakeOpt::More(0))?;
             if self.sym(b',').is_err() {
@@ -239,16 +302,16 @@ impl<R: repr::Repr> Parser<'_, R> {
                 }
                 k
             } else {
-                err!(
-                    self.scalar_flow(level + 1, true),
-                    self.err("flow map value")
-                )?
+                err!(self.scalar_flow(level + 1, true), self.err("flow map key"))?
             };
             if self.sym(b':').is_err() || self.bound().is_err() {
-                return self.err("map");
+                return self.err("flow map splitter");
             }
             self.forward();
-            let v = err!(self.scalar(level + 1, false, true), self.err("map"))?;
+            let v = err!(
+                self.scalar(level + 1, false, true),
+                self.err("flow map value")
+            )?;
             m.push((k, v));
             if self.sym(b',').is_err() {
                 self.inv(TakeOpt::More(0))?;
@@ -260,25 +323,26 @@ impl<R: repr::Repr> Parser<'_, R> {
         Ok(m.into_iter().collect())
     }
 
-    /// Match array.
-    pub fn array(&mut self, level: usize, nest: bool) -> Result<YamlBase<R>, PError> {
+    /// Match sequence.
+    pub fn seq(&mut self, level: usize, nest: bool) -> Result<YamlBase<R>, PError> {
         let mut v = vec![];
         loop {
             self.forward();
             let mut downgrade = false;
             if v.is_empty() {
-                // Mismatch
+                // First item
                 if nest {
                     self.gap(true)?;
-                    downgrade = self.unind(level)?;
+                    self.ind_define(level)?;
                 } else if self.gap(true).is_ok() {
-                    downgrade = self.unind(level)?;
+                    // Root
+                    self.unind(level)?;
                 }
                 self.sym(b'-')?;
                 self.bound()?;
             } else {
                 if self.gap(true).is_err() {
-                    return self.err("array terminator");
+                    return self.err("sequence terminator");
                 }
                 if self.doc_end() {
                     break;
@@ -295,7 +359,7 @@ impl<R: repr::Repr> Parser<'_, R> {
             self.forward();
             v.push(err!(
                 self.scalar(if downgrade { level } else { level + 1 }, false, false),
-                self.err("array item")
+                self.err("sequence item")
             )?);
         }
         // Keep last wrapping
@@ -309,11 +373,12 @@ impl<R: repr::Repr> Parser<'_, R> {
         loop {
             self.forward();
             let k = if m.is_empty() {
-                // Mismatch
+                // First item
                 if nest {
                     self.gap(true)?;
-                    self.ind(level)?;
+                    self.ind_define(level)?;
                 } else if self.gap(true).is_ok() {
+                    // Root
                     self.ind(level)?;
                 }
                 self.forward();
@@ -365,62 +430,38 @@ impl<R: repr::Repr> Parser<'_, R> {
     }
 }
 
-macro_rules! impl_parser {
-    ($(#[$meta:meta])* $func:ident -> $repr:ty) => {
-        $(#[$meta])*
-        pub fn $func(doc: &str) -> Result<(Array<$repr>, AnchorBase<$repr>), String> {
-            let mut p = Parser::<$repr>::new(doc.as_bytes());
-            p.parse()
-                .map_err(|e| e.into_error(doc))
-                .map(|a| (a, p.anchors))
-        }
-    };
-}
-
-impl_parser! {
-    /// Parse YAML document into [`alloc::rc::Rc`] data holder.
-    /// Return an array of nodes and the anchors.
-    ///
-    /// ```
-    /// use yaml_peg::{parse, node};
-    ///
-    /// let doc = "
-    /// ---
-    /// name: Bob
-    /// married: true
-    /// age: 46
-    /// ";
-    /// let (n, anchors) = parse(doc).unwrap();
-    /// assert_eq!(anchors.len(), 0);
-    /// assert_eq!(n, vec![node!({
-    ///     "name" => "Bob",
-    ///     "married" => true,
-    ///     "age" => 46,
-    /// })]);
-    /// ```
-    parse -> repr::RcRepr
-}
-
-impl_parser! {
-    /// Parse YAML document into [`alloc::sync::Arc`] data holder.
-    /// Return an array of nodes and the anchors.
-    ///
-    /// ```
-    /// use yaml_peg::{parse_arc, node_arc};
-    ///
-    /// let doc = "
-    /// ---
-    /// name: Bob
-    /// married: true
-    /// age: 46
-    /// ";
-    /// let (n, anchors) = parse_arc(doc).unwrap();
-    /// assert_eq!(anchors.len(), 0);
-    /// assert_eq!(n, vec![node_arc!({
-    ///     "name" => "Bob",
-    ///     "married" => true,
-    ///     "age" => 46,
-    /// })]);
-    /// ```
-    parse_arc -> repr::ArcRepr
+/// Parse YAML document into [`alloc::rc::Rc`] or [`alloc::sync::Arc`] data holder.
+/// Return an sequence of nodes and the anchors.
+///
+/// ```
+/// use yaml_peg::{parse, node};
+///
+/// let doc = "
+/// ---
+/// name: Bob
+/// married: true
+/// age: 46
+/// ";
+/// // Node with Rc repr
+/// let (n, anchors) = parse(doc).unwrap();
+/// assert_eq!(anchors.len(), 0);
+/// assert_eq!(n, vec![node!({
+///     "name" => "Bob",
+///     "married" => true,
+///     "age" => 46,
+/// })]);
+/// // Node with Arc repr
+/// let (n, anchors) = parse(doc).unwrap();
+/// assert_eq!(anchors.len(), 0);
+/// assert_eq!(n, vec![node!(arc{
+///     "name" => "Bob",
+///     "married" => true,
+///     "age" => 46,
+/// })]);
+/// ```
+pub fn parse<R: Repr>(doc: &str) -> Result<(Seq<R>, AnchorBase<R>), String> {
+    let mut p = Parser::new(doc.as_bytes());
+    p.parse()
+        .map_err(|e| e.into_error(doc))
+        .map(|a| (a, p.anchors))
 }
