@@ -1,11 +1,14 @@
-use super::*;
+use crate::*;
+use alloc::string::ToString;
 
-const TEST_JSON: &str = include_str!("test.json");
-const TEST_YAML: &str = include_str!("test.yaml");
+fn show_err<E>(e: String) -> E {
+    panic!("{}", e)
+}
 
 #[test]
 fn test_json() {
-    let (ans, anchors) = parse(TEST_JSON).unwrap_or_else(|e| panic!("{}", e));
+    const DOC: &str = include_str!("json_compatibility.json");
+    let (ans, anchors) = parse(DOC).unwrap_or_else(show_err);
     assert_eq!(anchors.len(), 0);
     assert_eq!(anchor_visit(&ans[0]), anchors);
     assert_eq!(
@@ -13,7 +16,8 @@ fn test_json() {
         node!({
             "a" => "b",
             "c" => node!([123, 321, 1234567]),
-            "d" => node!({})
+            "d" => node!({}),
+            "e:f" => "g"
         })
     );
     let n = ans[0].get("a").unwrap();
@@ -22,7 +26,8 @@ fn test_json() {
 
 #[test]
 fn test_yaml() {
-    let (ans, anchors) = parse(TEST_YAML).unwrap_or_else(|e| panic!("{}", e));
+    const DOC: &str = include_str!("complete_doc.yaml");
+    let (ans, anchors) = parse(DOC).unwrap_or_else(show_err);
     assert_eq!(anchors.len(), 2);
     assert!(anchors.contains_key("x"));
     assert!(anchors.contains_key("y"));
@@ -77,7 +82,7 @@ fn test_yaml() {
 
 #[test]
 fn test_dump() {
-    use crate::dumper::NL;
+    const DOC: &str = include_str!("dump_result.yaml");
     let doc = dump(&[
         node!({
             "a" => "b",
@@ -89,17 +94,25 @@ fn test_dump() {
         }),
         node!(["a", "b"]),
     ]);
-    let ans = "\
-a: b
-c:
-  - d: e
-  - f:
-      g: h
-  - i:
-    - j
----
-- a
-- b
-";
-    assert_eq!(doc, ans.replace('\n', NL));
+    assert_eq!(doc.replace("\r\n", "\n"), DOC.replace("\r\n", "\n"));
+}
+
+#[test]
+fn test_indent() {
+    const DOC: &str = include_str!("indent.yaml");
+    let (ans, _) = parse(DOC).unwrap_or_else(show_err);
+    assert_eq!(
+        ans[0],
+        node!({
+            "version" => 2,
+            "models" => node!([node!({
+                "name" => "orders",
+                "columns" => node!([node!({
+                    "name" => "c_custkey",
+                    "tests" => node!(["not_null"]),
+                })]),
+            })]),
+        })
+    );
+    assert_eq!(ans[1], node!(["a1", "true of", "a2"]));
 }
